==> ck_content_injector-6.x-1.0.tar.gz: ck_content_injector/ck_plugin/ck_content_injector/plugin.js <==
/*
 * @file
 * CK Content Injector Plugin.
 * Plugin to inject a template in the editor.
 *
 */

/**
 * Register the CK Content Injector plugin with CKEditor.
 */
CKEDITOR.plugins.add( 'ck_content_injector',
{
  lang: ['en'],

  init: function( editor )
  {
    /**
     * Register the 'command' we are creating with the CKEditor.
     */
    editor.addCommand( 'LoadCKContentInjector', new CKEDITOR.dialogCommand( 'LoadCKContentInjector' ) );

    /**
     * Create the toolbar button.
     */
    editor.ui.addButton( 'ck_content_injector',
    {
      label: editor.lang.ck_content_injector.btn,
      command: 'LoadCKContentInjector',
      icon: this.path + 'toolbaricon.gif'
    });

    /**
     * Detect double-click events. We are particularly interested in the user
     * double-clicking on a "TEMPLATE" <SPAN> tag, where we should counteract
     * any attempts by the browser to select other elements as well.
     */
    editor.on( 'doubleclick', function(event) {
      if (editor.readOnly)
        return;
      // Get the element that was clicked on.
      var targetElement = event.data.element;
      // Test if the clicked element is a "TEMPLATE" span.
      if ( targetElement && targetElement.is('span') ) {
        if( targetElement.getText().substr(0, 10) == '[[TEMPLATE') {
          // Trim the selection down to just our element.
          editor.getSelection().selectElement(targetElement);
          //editor.openDialog( 'LoadCKContentInjector' );
        }
      }
    });

    /**
     * Detect when the user changes the active selection in the editor area. We
     * are particularly interested in when they click on "TEMPLATE" <SPAN> tags,
     * so we save a reference to the currently active one in a variable.
     */
    editor.on( 'selectionChange', function(event) {
      if (editor.readOnly)
        return;
      // Get the element that was selected.
      var selectedElement = event.data.element;
      // We're only interested in selection changes to our "TEMPLATE" span tags.
      if ( selectedElement && selectedElement.is('span') && selectedElement.getText().substr(0, 10) == '[[TEMPLATE') {
        // Store the clicked element in our object.
        CK_Content_Injector.selectedTemplateTag = selectedElement;
      }
      else {
        // Reset the clicked element reference.
        CK_Content_Injector.selectedTemplateTag = null;
      }
    });

    /**
     * Highlight existing injector template tags in this document.
     */
    editor.on( 'instanceReady', function(event) {
      CK_Content_Injector.FindTemplateTags(editor);
    });

    /**
     * Create the dialog box associated with this plugin.
     */
    CKEDITOR.dialog.add( 'LoadCKContentInjector', CKEDITOR.getUrl( this.path + 'dialogs/ck_content_injector.js' ) );
  }
});

/**
 * The object used for all operations.
 */
var CK_Content_Injector = {
  editor : null,
  templateSelectorId : null,
  selectedTemplateTag : null,
  injectorTemplates : []
};

/**
 * Loads in a list of the available templates. This function uses the Drupal
 * module's "get_template_list" function to get them.
 */
CK_Content_Injector.loadTemplateList = function() {
  $.get('/admin/ck_content_injector/get_template_list', {}, function(data) {
    CK_Content_Injector.injectorTemplates = [];
    CK_Content_Injector.injectorTemplates = data;
  }, 'json');
}

/**
 * Fills the template selection drop-down box with either a list of available
 * templates (if no template tag is currently selected), or the filename of the
 * current tag (if one is).
 */
CK_Content_Injector.populateTemplatesDropdown = function(selectedTemplate) {
  // Get a reference to the template selection drop-down box.
  var dd = document.getElementById(CK_Content_Injector.templateSelectorId);
  // Empty the drop-down.
  dd.options.length = 0;
  // If a "TEMPLATE" tag was highlighted in the editor, add its type as the only available option.
  if (''!=selectedTemplate) {
    var newOption = document.createElement('OPTION');
    newOption.text = CK_Content_Injector.injectorTemplates[selectedTemplate];
    newOption.value = selectedTemplate;
    newOption.selected = true;
    dd.options.add(newOption);
  }
  // Otherwise, no "TEMPLATE" tag was highlighted so present a blank form.
  else {
    // Empty the form.
    CK_Content_Injector.templateSelectionChanged();
    // Add the 'Please select...' option first to the drop-down.
    var pleaseSelectOption = document.createElement('OPTION');
    pleaseSelectOption.text = this.editor.lang.ck_content_injector.pleaseSelect;
    pleaseSelectOption.value = '';
    pleaseSelectOption.selected = true;
    dd.options.add(pleaseSelectOption);
    // Now add each available injector template as a separate option.
    for (var templateName in CK_Content_Injector.injectorTemplates) {
      var newOption = document.createElement('OPTION');
      newOption.text = CK_Content_Injector.injectorTemplates[templateName];
      newOption.value = templateName;
      dd.options.add(newOption);
    }
  }
}

/**
 * Fills the fields in the template form with the variables from the currently-
 * selected "TEMPLATE" tag.
 */
CK_Content_Injector.populateTemplateForm = function(templateVars) {
  // Break the template variables string into its components.
  var aParts = Array.prototype.slice.call(templateVars);
  // Attempt to get a reference to a field corresponding to the current component.
  for (var i = 1; i < aParts.length; i++) {
    var field = document.getElementById('t_field_'+(i-1));
    // If the field exists, attempt to set its value.
    if (field != undefined) {
      var value = unescape(aParts[i]);
      if( tidyUps[i-1]) {
        for (var j in tidyUps[i-1]) {
          if (value == j) {
            value = tidyUps[i-1][j];
            break;
          }
        }
      }
      field.value = value;
    }
  }
};

/**
 * Triggered when the template selection drop-down box is changed. Fills the
 * form DIV with the appropriate form fields for the chosen template.
 */
CK_Content_Injector.templateSelectionChanged = function(template, callback, aParts) {
  if (!template) {
    $('#formContents').empty();
    return;
  }
  if (callback && 'function'==typeof callback && aParts) {
    $('#formContents').load('/admin/ck_content_injector/load_form_content', { plugin: template }, function() { callback.apply(window, aParts) });
  }
  else {
    $('#formContents').load('/admin/ck_content_injector/load_form_content', { plugin: template });
  }
};

/**
 * Adds a new "TEMPLATE" <SPAN> tag at the current location (selection) in the
 * editor, giving it the parameters sent to this function.
 */
CK_Content_Injector.Add = function() {
  // Create the new <SPAN> tag that we will be inserting into the document.
  var oSpan = new CKEDITOR.dom.element('SPAN');
  // Break apart the arguments sent to this function.
  var args = Array.prototype.slice.call(arguments);
  // Add our new span tag to the new array of arguments.
  args.unshift(oSpan);
  // Call a helper function that customises this <SPAN> tag.
  this.SetupSpan.apply(this, args);
  // Insert the new <SPAN> tag into the document.
  CK_Content_Injector.editor.insertElement(oSpan);
}

/**
 * Helper function for configuring a new "TEMPLATE" <SPAN> document element with
 * the correct parameters.
 */
CK_Content_Injector.SetupSpan = function() {
  var args = Array.prototype.slice.call(arguments);
  var span = args.shift();
  // Customise the look and feel of the <SPAN> tag.
  span.setHtml('[[TEMPLATE ' + args.join(',') + ' ]]');
  this.StyleSpan(span);
}

/**
 * Helper function to apply styling to a "TEMPLATE" <SPAN> document element.
 */
CK_Content_Injector.StyleSpan = function(spanElement) {
  if(spanElement) {
    spanElement.setStyles({
      'background-color' : '#ccffcc',
      'color' : '#000000'
    });
    spanElement.setAttributes({
      'contenteditable' : 'false'
    });
    if (CKEDITOR.env.gecko) {
      spanElement.setStyle('cursor', 'default');
    }
  }
  else {
    return 'style="background-color: #ccffcc; color: #000000; cursor: default;" contenteditable="false"';
  }
}

/**
 * Search the given editor instance for content injector TEMPLATE tags and wrap
 * them in <SPAN> tags.
 */
CK_Content_Injector.FindTemplateTags = function(editor) {
  if(!editor) {
    if(CK_Content_Injector.editor) {
      editor = CK_Content_Injector.editor;
    }
    else {
      return;
    }
  }
  var body = editor.document.getBody().$;
  body.innerHTML = body.innerHTML.replace(/(<span(.*?)>)?(\[\[TEMPLATE\s*([^\]]*?)\s*\]\])(<\/span>)?/g, '<span ' + CK_Content_Injector.StyleSpan() + '>$3</span>');
}

/**
 * Load a list of the available templates when the page is ready.
 */
$(function(){
  CK_Content_Injector.loadTemplateList();
});

==> ck_content_injector-6.x-1.2.tar.gz: ck_content_injector/ck_plugin/ck_content_injector/plugin.js <==
/*
 * @file
 * CK Content Injector Plugin.
 * Plugin to inject a template in the editor.
 *
 */

/**
 * Register the CK Content Injector plugin with CKEditor.
 */
CKEDITOR.plugins.add( 'ck_content_injector',
{
  lang: ['en'],

  init: function( editor )
  {
    /**
     * Register the 'command' we are creating with the CKEditor.
     */
    editor.addCommand( 'LoadCKContentInjector', new CKEDITOR.dialogCommand( 'LoadCKContentInjector' ) );

    /**
     * Create the toolbar button.
     */
    editor.ui.addButton( 'ck_content_injector',
    {
      label: editor.lang.ck_content_injector.btn,
      command: 'LoadCKContentInjector',
      icon: this.path + 'toolbaricon.gif'
    });

    /**
     * Detect double-click events. We are particularly interested in the user
     * double-clicking on a "TEMPLATE" <SPAN> tag, where we should counteract
     * any attempts by the browser to select other elements as well.
     */
    editor.on( 'doubleclick', function(event) {
      if (editor.readOnly)
        return;
      // Get the element that was clicked on.
      var targetElement = event.data.element;
      // Test if the clicked element is a "TEMPLATE" span.
      if ( targetElement && targetElement.is('span') ) {
        if( targetElement.getText().substr(0, 10) == '[[TEMPLATE') {
          // Trim the selection down to just our element.
          editor.getSelection().selectElement(targetElement);
          //editor.openDialog( 'LoadCKContentInjector' );
        }
      }
    });

    /**
     * Detect when the user changes the active selection in the editor area. We
     * are particularly interested in when they click on "TEMPLATE" <SPAN> tags,
     * so we save a reference to the currently active one in a variable.
     */
    editor.on( 'selectionChange', function(event) {
      if (editor.readOnly)
        return;
      // Get the element that was selected.
      var selectedElement = event.data.element;
      // We're only interested in selection changes to our "TEMPLATE" span tags.
      if ( selectedElement && selectedElement.is('span') && selectedElement.getText().substr(0, 10) == '[[TEMPLATE') {
        // Store the clicked element in our object.
        CK_Content_Injector.selectedTemplateTag = selectedElement;
      }
      else {
        // Reset the clicked element reference.
        CK_Content_Injector.selectedTemplateTag = null;
      }
    });

    /**
     * Highlight existing injector template tags in this document.
     */
    editor.on( 'instanceReady', function(event) {
      CK_Content_Injector.FindTemplateTags(editor);
    });

    /**
     * Create the dialog box associated with this plugin.
     */
    CKEDITOR.dialog.add( 'LoadCKContentInjector', CKEDITOR.getUrl( this.path + 'dialogs/ck_content_injector.js' ) );
  }
});

/**
 * The object used for all operations.
 */
var CK_Content_Injector = {
  editor : null,
  templateSelectorId : null,
  selectedTemplateTag : null,
  injectorTemplates : []
};

/**
 * Loads in a list of the available templates. This function uses the Drupal
 * module's "get_template_list" function to get them.
 */
CK_Content_Injector.loadTemplateList = function() {
  $.get(Drupal.settings.basePath + 'admin/ck_content_injector/get_template_list', {}, function(data) {
    CK_Content_Injector.injectorTemplates = [];
    CK_Content_Injector.injectorTemplates = data;
  }, 'json');
}

/**
 * Fills the template selection drop-down box with either a list of available
 * templates (if no template tag is currently selected), or the filename of the
 * current tag (if one is).
 */
CK_Content_Injector.populateTemplatesDropdown = function(selectedTemplate) {
  // Get a reference to the template selection drop-down box.
  var dd = document.getElementById(CK_Content_Injector.templateSelectorId);
  // Empty the drop-down.
  dd.options.length = 0;
  // If a "TEMPLATE" tag was highlighted in the editor, add its type as the only available option.
  if (''!=selectedTemplate) {
    var newOption = document.createElement('OPTION');
    newOption.text = CK_Content_Injector.injectorTemplates[selectedTemplate];
    newOption.value = selectedTemplate;
    newOption.selected = true;
    dd.options.add(newOption);
  }
  // Otherwise, no "TEMPLATE" tag was highlighted so present a blank form.
  else {
    // Empty the form.
    CK_Content_Injector.templateSelectionChanged();
    // Add the 'Please select...' option first to the drop-down.
    var pleaseSelectOption = document.createElement('OPTION');
    pleaseSelectOption.text = this.editor.lang.ck_content_injector.pleaseSelect;
    pleaseSelectOption.value = '';
    pleaseSelectOption.selected = true;
    dd.options.add(pleaseSelectOption);
    // Now add each available injector template as a separate option.
    for (var templateName in CK_Content_Injector.injectorTemplates) {
      var newOption = document.createElement('OPTION');
      newOption.text = CK_Content_Injector.injectorTemplates[templateName];
      newOption.value = templateName;
      dd.options.add(newOption);
    }
  }
}

/**
 * Fills the fields in the template form with the variables from the currently-
 * selected "TEMPLATE" tag.
 */
CK_Content_Injector.populateTemplateForm = function(templateVars) {
  // Break the template variables string into its components.
  var aParts = Array.prototype.slice.call(templateVars);
  // Attempt to get a reference to a field corresponding to the current component.
  for (var i = 1; i < aParts.length; i++) {
    var field = document.getElementById('t_field_'+(i-1));
    // If the field exists, attempt to set its value.
    if (field != undefined) {
      var value = unescape(aParts[i]);
      if( tidyUps[i-1]) {
        for (var j in tidyUps[i-1]) {
          if (value == j) {
            value = tidyUps[i-1][j];
            break;
          }
        }
      }
      field.value = value;
    }
  }
};

/**
 * Triggered when the template selection drop-down box is changed. Fills the
 * form DIV with the appropriate form fields for the chosen template.
 */
CK_Content_Injector.templateSelectionChanged = function(template, callback, aParts) {
  if (!template) {
    $('#formContents').empty();
    return;
  }
  if (callback && 'function'==typeof callback && aParts) {
    $('#formContents').load(Drupal.settings.basePath + 'admin/ck_content_injector/load_form_content', { plugin: template }, function() { callback.apply(window, aParts) });
  }
  else {
    $('#formContents').load(Drupal.settings.basePath + 'admin/ck_content_injector/load_form_content', { plugin: template });
  }
};

/**
 * Adds a new "TEMPLATE" <SPAN> tag at the current location (selection) in the
 * editor, giving it the parameters sent to this function.
 */
CK_Content_Injector.Add = function() {
  // Create the new <SPAN> tag that we will be inserting into the document.
  var oSpan = new CKEDITOR.dom.element('SPAN');
  // Break apart the arguments sent to this function.
  var args = Array.prototype.slice.call(arguments);
  // Add our new span tag to the new array of arguments.
  args.unshift(oSpan);
  // Call a helper function that customises this <SPAN> tag.
  this.SetupSpan.apply(this, args);
  // Insert the new <SPAN> tag into the document.
  CK_Content_Injector.editor.insertElement(oSpan);
}

/**
 * Helper function for configuring a new "TEMPLATE" <SPAN> document element with
 * the correct parameters.
 */
CK_Content_Injector.SetupSpan = function() {
  var args = Array.prototype.slice.call(arguments);
  var span = args.shift();
  // Customise the look and feel of the <SPAN> tag.
  span.setHtml('[[TEMPLATE ' + args.join(',') + ' ]]');
  this.StyleSpan(span);
}

/**
 * Helper function to apply styling to a "TEMPLATE" <SPAN> document element.
 */
CK_Content_Injector.StyleSpan = function(spanElement) {
  if(spanElement) {
    spanElement.setStyles({
      'background-color' : '#ccffcc',
      'color' : '#000000'
    });
    spanElement.setAttributes({
      'contenteditable' : 'false'
    });
    if (CKEDITOR.env.gecko) {
      spanElement.setStyle('cursor', 'default');
    }
  }
  else {
    return 'style="background-color: #ccffcc; color: #000000; cursor: default;" contenteditable="false"';
  }
}

/**
 * Search the given editor instance for content injector TEMPLATE tags and wrap
 * them in <SPAN> tags.
 */
CK_Content_Injector.FindTemplateTags = function(editor) {
  if(!editor) {
    if(CK_Content_Injector.editor) {
      editor = CK_Content_Injector.editor;
    }
    else {
      return;
    }
  }
  var body = editor.document.getBody().$;
  body.innerHTML = body.innerHTML.replace(/(<span(.*?)>)?(\[\[TEMPLATE\s*([^\]]*?)\s*\]\])(<\/span>)?/g, '<span ' + CK_Content_Injector.StyleSpan() + '>$3</span>');
}

/**
 * Load a list of the available templates when the page is ready.
 */
$(function(){
  CK_Content_Injector.loadTemplateList();
});
